pub enum AssociateLexBotError {
InternalService(String),
InvalidParameter(String),
InvalidRequest(String),
ResourceConflict(String),
ResourceNotFound(String),
ServiceQuotaExceeded(String),
Throttling(String),
}Expand description
Errors returned by AssociateLexBot
Variants
InternalService(String)
Request processing failed because of an error or failure with the service.
InvalidParameter(String)
One or more of the specified parameters are not valid.
InvalidRequest(String)
The request is not valid.
ResourceConflict(String)
A resource already has that name.
ResourceNotFound(String)
The specified resource was not found.
ServiceQuotaExceeded(String)
The service quota has been exceeded.
Throttling(String)
The throttling limit has been exceeded.
Implementations
Sourceimpl AssociateLexBotError
impl AssociateLexBotError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<AssociateLexBotError>