pub enum DisassociateLambdaFunctionError {
InternalService(String),
InvalidParameter(String),
InvalidRequest(String),
ResourceNotFound(String),
Throttling(String),
}Expand description
Errors returned by DisassociateLambdaFunction
Variants
InternalService(String)
Request processing failed because of an error or failure with the service.
InvalidParameter(String)
One or more of the specified parameters are not valid.
InvalidRequest(String)
The request is not valid.
ResourceNotFound(String)
The specified resource was not found.
Throttling(String)
The throttling limit has been exceeded.
Implementations